#Boxplot of Fusarium growth inhibition (3DPI) on six media - Fig 2
#Reference dataset "Dataset_antibiosistest.xlsx"
library(readxl)
library(ggplot2)
library(ggthemes)
library(RColorBrewer)
data<-Dataset_antibiosistest
myColors <- c(brewer.pal(6,"Set2"))
fillScale<-scale_fill_manual(values=myColors)
p<-ggplot(data)
p<-p+geom_boxplot(aes(y=Growth_inhibition,x=Media,fill=Media))
p<-p+theme(axis.text.x=element_blank(),axis.ticks=element_blank())+ylab("Fusarium growth inhibition (%)")
p<-p+theme(legend.position = "bottom")
windowsFonts(Times=windowsFont("TT Times New Roman"))
p<-p+theme(axis.title.x=element_blank(),axis.title.y = element_text(family = "Times"),axis.text = element_text(family = "Times"),strip.text = element_text(family = "Times") , legend.text = element_text(family = "Times"),legend.title = element_text(family = "Times"))
p<-p+facet_grid(Fung~Strepto)+fillScale
p
ggsave("boxplot.png",device="png",path =" ",dpi=600,width=12,height=8)

#REGRESSION ANALYSIS on Fusarium growth inhibition (3DPI) - FUSARIUM FG8/1 AND MEDIUM PDA1 FIXED AS BASELINE - Table 2
#Reference dataset "Dataset_antibiosistest.xlsx"
data$Strepto<-as.factor(data$Strepto)
data$Fung<-as.factor(data$Fung)
data$Media<-as.factor(data$Media)
data$Fung<-relevel(data$Fung,ref="Fg8/1")
data$Media<-relevel(data$Media,ref="PDA1")
aov.m <- aov(Growth_inhibition ~ Media, data=data)
summary(aov.m)
aov.f <- aov(Growth_inhibition ~ Fung, data=data)
summary(aov.f)
aov.f.m <- aov(Growth_inhibition ~ Fung+Media, data=data)
summary(aov.f.m)
aov.f.m.f.x.m <- aov(Growth_inhibition ~ Fung+Media+ Fung*Media, data=data)
summary(aov.f.m.f.x.m)

lm.m <- lm(Growth_inhibition ~ Media, data=data)#MODEL 1
lm.f <- lm(Growth_inhibition ~ Fung, data=data)#MODEL 2
lm.f.m <- lm(Growth_inhibition ~ Fung+Media, data=data)#MODEL 3
lm.f.m.f.x.m <- lm(Growth_inhibition ~ Fung+Media+ Fung*Media, data=data)#MODEL 4
#Model comparison with ANOVA - TABLE 3
anova(lm.m,lm.f,lm.f.m,lm.f.m.f.x.m)
#Multiple linear regression with all parameters and interactions - TABLE 4
summary(inhib.f.m <- lm(Growth_inhibition ~ Fung*Media, data=data))

#ANOVA BAYES FACTOR analysis on Fusarium growth inhibition (3DPI) - TABLE 3
library(BayesFactor)
bf<-anovaBF(Growth_inhibition ~ Media*Fung, data=data)
bf
prior.odds = newPriorOdds(bf, type = "equal")
post.odds = prior.odds * bf
post.prob = as.BFprobability(post.odds)
post.prob


# Comparison of experiment 1 and 2_t-test
#Reference dataset for 3DPI "WMA-FG8_3DPI.xlsx"
data3 <- read_excel("C:/PC_Cristina/Fusarium_Elena/Dati Elena/Data_peerj/Stat_peerj_resubmission/WMA-FG8_3DPI.xlsx")
summary(data3)
t.test(data3$First_experiment, data3$Second_experiment, paired = F)
#Reference dataset for 7DPI "WMA-FG8_7DPI.xlsx"
data7 <- read_excel("C:/PC_Cristina/Fusarium_Elena/Dati Elena/Data_peerj/Stat_peerj_resubmission/WMA-FG8_7DPI.xlsx")
summary(data7)
t.test(data7$First_experiment, data7$Second_experiment, paired = F)

#PEARSON CORRELATION BETWEEN IN VIVO ROOT ROT INHIBITION (4DPI) AND IN VITRO DUAL CULTURE RESULTS (3DPI) - Fig 3A
#Reference dataset "Corr_vivo_vitro4dpi.xlsx" and "vivo_vitro_all_4dpi_for graph.xls"
library(ggpmisc)
vivo4<-Corr_vivo_vitro4dpi
corr4 <- round(cor(vivo4),2)
prova <- vivo_vitro_all_4dpi_for graph
myColors <- c(brewer.pal(6,"Set2"))
names(myColors)<-c("CZY","MMNAG","PDA1","PDA2","WFA","WMA")
colScale<-scale_color_manual(name="Media", values=myColors)
p<-ggplot(prova,aes(x=Vivo,y=Vitro,col=Media))
p<-p+geom_point()
corr.facet<-list("PDA1"="PDA1 ( r = -0.47 )","PDA2"="PDA2 ( r = -0.54 )","CZY"="CZY ( r = 0.18 )","WFA"="WFA ( r = -0.19 )","MMNAG"="MMNAG ( r = -0.12 )","WMA"="WMA ( r = 0.5 )")
media_labeller <- function(variable,value){
  return(corr.facet[value])
}
windowsFonts(Times=windowsFont("TT Times New Roman"))
p+theme(plot.title = element_text(size=16,family = "Times"), axis.title = element_text(size=12,family = "Times"),axis.text = element_text(size=12,family = "Times"),strip.text = element_text(size=12,family = "Times") , legend.text = element_text(size=16,family = "Times"),legend.title = element_text(size=16,family = "Times"))
p<-p+facet_wrap(~Media,labeller=media_labeller)
p<-p+ylim(0,100)
p<-p+labs(x="In vivo inhibition (%)", y="In vitro inhibition (%)")
p<-p+colScale
p
ggsave("correlazione_4dpi.png",device="png",path="C:/Users/Alberto/Desktop/Elena/",dpi=600,width=8,height=8)


#PEARSON CORRELATION BETWEEN IN VIVO FOOT ROT INHIBITION (6DPI) AND IN VITRO DUAL CULTURE RESULTS (3DPI)-Fig 3B
#Reference dataset "Corr_vivo_vitro6dpi.xlsx" and "vivo_vitro_all_6dpi_for graph.xls"
vivo6 <- Corr_vivo_vitro6dpi
corr6 <- round(cor(vivo6),2)
prova1<- vivo_vitro_all_6dpi_for graph
myColors <- c(brewer.pal(6,"Set2"))
names(myColors)<-c("CZY","MMNAG","PDA1","PDA2","WFA","WMA")
colScale<-scale_color_manual(name="Media", values=myColors)
p1<-ggplot(prova1,aes(x=Vivo,y=Vitro,col=Media))
p1<-p1+geom_point()
corr.facet<-list("PDA1"="PDA1 ( r = 0.02 )","PDA2"="PDA2 ( r = 0.09 )","CZY"="CZY ( r = 0.04 )","WFA"="WFA ( r = -0.10 )","MMNAG"="MMNAG ( r = -0.33 )","WMA"="WMA ( r = -0.17)")
media_labeller <- function(variable,value){
  return(corr.facet[value])
}
p1<-p1+theme(plot.title = element_text(size=16,family = "Times"), axis.title = element_text(size=12,family = "Times"),axis.text = element_text(size=12,family = "Times"),strip.text = element_text(size=12,family = "Times") , legend.text = element_text(size=12,family = "Times"),legend.title = element_text(size=12,family = "Times"))
p1<-p1+facet_wrap(~Media,labeller=media_labeller)
p1<-p1+ylim(0,100)
p1<-p1+labs(x="In vivo inhibition (%)", y="In vitro inhibition (%)")
p1<-p1+colScale
p1
ggsave("correlazione_6dpi.png",device="png",path="C:/Users/Alberto/Desktop/Elena/",dpi=600,width=8,height=8)

#PEARSON CORRELATION BETWEEN IN VIVO FOOT ROT INHIBITION (6DPI) DATA AND IN VITRO WMA DUAL CULTURE RESULTS (7DPI)
#Reference dataset "Corr_vivo_vitro7dpi.xls"
vivoF <- Corr_vivo_vitro7dpi
corrF <- round(cor(vivoF),2)
corrF















```